# Tool-Use Instructions

You have access to a set of tools provided via the Model Context Protocol (MCP). Use tools step-by-step to accomplish tasks.

Each tool call should include:
- server_name: The name of the MCP server providing the tool
- tool_name: The name of the tool to execute
- arguments: A JSON object containing the tool's input parameters

Follow the tool's input schema for required and optional parameters.
